==> qutim_0.2.60-maemo-8.tar.gz: qutim-0.2.60-maemo/translations/bg_BG/nowplaying.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim-meta/plugins/nowplaying/src/nowplaying.cpp" line="+32"/>
        <source>Kazlauskas Ian</source>
        <translation>Ян Казлаускас</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alexey Prokhin</source>
        <translation>Алексей Прохин</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ruslan Nigmatullin</source>
        <translation>Руслан Нигматуллин</translation>
    </message>
</context>
<context>
    <name>IcqSettings</name>
    <message>
        <location filename="../../qutim-meta/plugins/nowplaying/src/icqsettings.ui" line="+14"/>
        <source>ICQ</source>
        <translation>ICQ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation>Текущ режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation>Деактивиранa</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Changes current X-status message</source>
        <translation>Променя съобщението на текущия разширен статус</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+33"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - artist&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - title&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - album&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - track number&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - track length&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - file name&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - full path to file&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - изпълнител&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - заглавие&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - албум&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - номер на изпълнението&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - продъ;жителност на изпълнението&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - име на файла&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - пълен път до файла&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Now playing: %artist - %title</source>
        <translation>В момента слушам: %artist - %title</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Changes message of &quot;Listening to music&quot; status</source>
        <translation>Променя съобщението на разширения статус &quot;Слушам музика&quot;</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>%artist - %title</source>
        <translation>%artist - %title</translation>
    </message>
</context>
<context>
    <name>JabberSettings</name>
    <message>
        <location filename="../../qutim-meta/plugins/nowplaying/src/jabbersettings.ui" line="+14"/>
        <source>Jabber</source>
        <translation>Jabber</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation>Текущ режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation>Деактивиранa</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Activated</source>
        <translation>Активирана</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Info to be presented</source>
        <translation>Показвана информация</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Artist</source>
        <translation>Изпълнител</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track number</source>
        <translation>Номер на изпълнението</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Title</source>
        <translation>Заглавие</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track length</source>
        <translation>Продължителност на изпълнението</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Path to file</source>
        <translation>Път до файла</translation>
    </message>
</context>
<context>
    <name>NowPlaying</name>
    <message>
        <location filename="../../qutim-meta/plugins/nowplaying/src/nowplaying.cpp" line="+39"/>
        <source>Now Playing</source>
        <translation>В момента слушам</translation>
    </message>
    <message>
        <location line="+184"/>
        <source>Stop now playing</source>
        <translation>Спиране на &quot;В момента слушам&quot;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start now playing</source>
        <translation>Пускане на &quot;В момента слушам&quot;</translation>
    </message>
</context>
<context>
    <name>NowPlayingSettings</name>
    <message>
        <location filename="../../qutim-meta/plugins/nowplaying/src/nowplayingsettings.ui" line="+17"/>
        <source>Form</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current plugin status:</source>
        <translation>Текущ статус на добавката:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Is working</source>
        <translation>Пусната</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Stop</source>
        <translation>Спиране</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Set mode for all accounts</source>
        <translation>Установяване за всички сметки</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>You have no Oscar, Jabber or MRIM accounts.</source>
        <translation>Липсват Oscar, Jabber или MRIM сметки.</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Music Player</source>
        <translation>Музикален плейър</translation>
    </message>
    <message>
        <source>Hostname</source>
        <translation type="obsolete">Име на хоста</translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="obsolete">Порт</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Парола</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim-meta/plugins/nowplaying/src/nowplaying.cpp" line="-233"/>
        <source>Now Playing</source>
        <translation>В момента слушам</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Now playing plugin</source>
        <translation>Добавка &quot;В момента слушам&quot;</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Now Playing Mpris</source>
        <translation>&quot;В момента слушам&quot; (Mpris)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mpris support for now playing plugin</source>
        <translation>Поддръжка на Mpris в добавката &quot;В момента слушам&quot;</translation>
    </message>
    <message>
        <source>MPRIS support</source>
        <translation type="obsolete">Поддръжка на MPRIS</translation>
    </message>
    <message>
        <source>Media Player Remote Interfacing Specification (MPRIS) support for now playing plugin</source>
        <translation type="obsolete">Поддръжка на Media Player Remote Interfacing Specification (MPRIS), за добавката</translation>
    </message>
    <message>
        <source>Now Playing Amarok 2</source>
        <translation type="obsolete">Добавка &quot;В момента слушам&quot; Amarok 2</translation>
    </message>
    <message>
        <source>Amarok 2 support for now playing plugin</source>
        <translation type="obsolete">Поддръжка на Amamrok 2 в добавката &quot;В момента слушам&quot;</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="-9"/>
        <location line="+3"/>
        <location line="+3"/>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::nowplaying::SettingsUI</name>
    <message>
        <location filename="../../qutim-meta/plugins/nowplaying/src/settingsui.cpp" line="+136"/>
        <source>working</source>
        <translation>пусната</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop</source>
        <translation>Спиране</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>not working</source>
        <translation>спряна</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start</source>
        <translation>Стартиране</translation>
    </message>
</context>
</TS>

==> qutim_0.2.80-maemo-8.tar.gz: qutim-0.2.80-maemo/translations/bg_BG/nowplaying.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Author</name>
    <message>
        <location filename="../../qutim/plugins/nowplaying/src/nowplaying.cpp" line="+33"/>
        <source>Kazlauskas Ian</source>
        <translation>Ян Казлаускас</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Alexey Prokhin</source>
        <translation>Алексей Прохин</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ruslan Nigmatullin</source>
        <translation>Руслан Нигматуллин</translation>
    </message>
</context>
<context>
    <name>IcqSettings</name>
    <message>
        <location filename="../../qutim/plugins/nowplaying/src/icqsettings.ui" line="+14"/>
        <source>ICQ</source>
        <translation>ICQ</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation>Текущ режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation>Деактивиранa</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Changes current X-status message</source>
        <translation>Променя съобщението на текущия разширен статус</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+33"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - artist&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - title&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - album&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - track number&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - track length&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - file name&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - full path to file&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;table style=&quot;-qt-table-type: root; margin-top:4px; margin-bottom:4px; margin-left:4px; margin-right:4px;&quot;&gt;
&lt;tr&gt;
&lt;td style=&quot;border: none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%artist - изпълнител&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%title - заглавие&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%album - албум&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%track - номер на изпълнението&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%time - продъ;жителност на изпълнението&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%file - име на файла&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans&apos;;&quot;&gt;%uri - пълен път до файла&lt;/span&gt;&lt;/p&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Now playing: %artist - %title</source>
        <translation>В момента слушам: %artist - %title</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Changes message of &quot;Listening to music&quot; status</source>
        <translation>Променя съобщението на разширения статус &quot;Слушам музика&quot;</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>%artist - %title</source>
        <translation>%artist - %title</translation>
    </message>
</context>
<context>
    <name>JabberSettings</name>
    <message>
        <location filename="../../qutim/plugins/nowplaying/src/jabbersettings.ui" line="+14"/>
        <source>Jabber</source>
        <translation>Jabber</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current mode</source>
        <translation>Текущ режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Deactivated</source>
        <translation>Деактивиранa</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Activated</source>
        <translation>Активирана</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Info to be presented</source>
        <translation>Показвана информация</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Artist</source>
        <translation>Изпълнител</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track number</source>
        <translation>Номер на изпълнението</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Title</source>
        <translation>Заглавие</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Track length</source>
        <translation>Продължителност на изпълнението</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Path to file</source>
        <translation>Път до файла</translation>
    </message>
</context>
<context>
    <name>NowPlaying</name>
    <message>
        <location filename="../../qutim/plugins/nowplaying/src/nowplaying.cpp" line="+39"/>
        <source>Now Playing</source>
        <translation>В момента слушам</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Stop now playing</source>
        <translation>Спиране на &quot;В момента слушам&quot;</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start now playing</source>
        <translation>Пускане на &quot;В момента слушам&quot;</translation>
    </message>
</context>
<context>
    <name>NowPlayingSettings</name>
    <message>
        <location filename="../../qutim/plugins/nowplaying/src/nowplayingsettings.ui" line="+17"/>
        <source>Form</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Current plugin status:</source>
        <translation>Текущ статус на добавката:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Is working</source>
        <translation>Пусната</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Stop</source>
        <translation>Спиране</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Set mode for all accounts</source>
        <translation>Установяване за всички сметки</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>You have no Oscar, Jabber or MRIM accounts.</source>
        <translation>Липсват Oscar, Jabber или MRIM сметки.</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Music Player</source>
        <translation>Музикален плейър</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../qutim/plugins/nowplaying/src/nowplaying.cpp" line="-236"/>
        <source>Now Playing</source>
        <translation>В момента слушам</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Now playing plugin</source>
        <translation>Добавка &quot;В момента слушам&quot;</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Now Playing Mpris</source>
        <translation>&quot;В момента слушам&quot; (Mpris)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mpris support for now playing plugin</source>
        <translation>Поддръжка на Mpris в добавката &quot;В момента слушам&quot;</translation>
    </message>
</context>
<context>
    <name>Task</name>
    <message>
        <location line="-9"/>
        <location line="+3"/>
        <location line="+3"/>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
</context>
<context>
    <name>qutim_sdk_0_3::nowplaying::SettingsUI</name>
    <message>
        <location filename="../../qutim/plugins/nowplaying/src/settingsui.cpp" line="+53"/>
        <source>No player</source>
        <translation>Без плейър</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>working</source>
        <translation>пусната</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop</source>
        <translation>Спиране</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>not working</source>
        <translation>спряна</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start</source>
        <translation>Стартиране</translation>
    </message>
</context>
</TS>
